Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetExitCode ¶
GetExitCode tries to retrieve the exit code from an exit error
func IsCommandOutputNop ¶
IsCommandOutputNop checks if a command exits with no output or error
Types ¶
type Command ¶
type Command struct {
Name string
Args []string
Env []string
Dir string
TeePipe bool
Process *os.Process
ProcessState *os.ProcessState
Stdin io.Reader
Stderr *bytes.Buffer
Stdout *bytes.Buffer
ExitCode int
Error error
// contains filtered or unexported fields
}
Command structure
Click to show internal directories.
Click to hide internal directories.