createctx

package
v1.0.0-alpha.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 27, 2016 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// ErrContainerPath indicates an invalid container location
	ErrContainerPath = errors.New("A container immediate parent dir must be the root of a project")

	// ErrProjectPath indicates an invalid project location
	ErrProjectPath = errors.New("A project can not have another project as its parent")

	// ErrInvalidID indicates an invalid resource ID (such as empty string)
	ErrInvalidID = errors.New("Value for resource ID is invalid")

	// ErrResourceExists indicates that two resource can not share the same location
	ErrResourceExists = errors.New("A resource already exists on the root of this location")
)

Functions

func New

func New() error

New creates a resource

func NewContainer

func NewContainer() error

NewContainer creates a container resource

func NewProject

func NewProject() error

NewProject creates a project resource

Types

This section is empty.

Jump to