package
Version:
v1.0.0-alpha-138
Opens a new window with list of versions in this module.
Published: Aug 4, 2017
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Error(a interface{}) string
Error formatter
func Info(a interface{}) string
Info formatter
func Question(a interface{}) string
Question formatter
func Success(a interface{}) string
Success formatter
func Tip(a interface{}) string
Tip formatter
Options selector
Ask for options printing a question
Source Files
¶
Click to show internal directories.
Click to hide internal directories.