findresource

package
v1.1.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 16, 2017 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetRootDirectory

func GetRootDirectory(dir, delimiter, file string) (string, error)

GetRootDirectory for a given file source

func GetSysRoot

func GetSysRoot() string

GetSysRoot returns the delimiter to stop searching for a resource

func SetSysRoot

func SetSysRoot(sr string) error

SetSysRoot sets the delimiter to stop searching for a resource

Types

This section is empty.

Jump to