flagsfromhost

package
v1.0.0-alpha-50 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 4, 2016 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func InjectRemotes

func InjectRemotes(list *remotes.List)

InjectRemotes list into the flagsfromhost module

func ParseRemoteAddress

func ParseRemoteAddress(remoteAddress string) (remote string, err error)

ParseRemoteAddress to get related remote

Types

type ErrorContainerWithNoProject

type ErrorContainerWithNoProject struct{}

ErrorContainerWithNoProject hapens when --container is used without --project

func (ErrorContainerWithNoProject) Error

type ErrorFoundMultipleRemote

type ErrorFoundMultipleRemote struct {
	Host    string
	Remotes []string
}

ErrorFoundMultipleRemote happens when multiple resolutions are found for a given host address

func (ErrorFoundMultipleRemote) Error

func (e ErrorFoundMultipleRemote) Error() string

type ErrorFoundNoRemote

type ErrorFoundNoRemote struct {
	Host string
}

ErrorFoundNoRemote happens when a remote isn't found for a given host address

func (ErrorFoundNoRemote) Error

func (e ErrorFoundNoRemote) Error() string

type ErrorLoadingRemoteList

type ErrorLoadingRemoteList struct{}

ErrorLoadingRemoteList happens when the remote list is needed, but not injected into the module

func (ErrorLoadingRemoteList) Error

type ErrorMultiMode

type ErrorMultiMode struct{}

ErrorMultiMode happens when --project and --container are used with host format

func (ErrorMultiMode) Error

func (ErrorMultiMode) Error() string

type ErrorNotFound

type ErrorNotFound struct {
	Remote string
}

ErrorNotFound happens when a remote isn't found

func (ErrorNotFound) Error

func (e ErrorNotFound) Error() string

type ErrorRemoteFlagAndHost

type ErrorRemoteFlagAndHost struct{}

ErrorRemoteFlagAndHost happens when both --remote and host remote are used together

func (ErrorRemoteFlagAndHost) Error

type FlagsFromHost

type FlagsFromHost struct {
	// contains filtered or unexported fields
}

FlagsFromHost holds the project, container, and remote parsed

func Parse

func Parse(host, project, container, remote string) (*FlagsFromHost, error)

Parse host and flags

func (*FlagsFromHost) Container

func (f *FlagsFromHost) Container() string

Container of the parsed flags or host

func (*FlagsFromHost) Project

func (f *FlagsFromHost) Project() string

Project of the parsed flags or host

func (*FlagsFromHost) Remote

func (f *FlagsFromHost) Remote() string

Remote of the parsed flags or host

Jump to