extra

package
v1.2.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 31, 2017 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package extra resolves legal compliance for copy & pasted code. If you need something pretty small it is wise to copy & paste code. This is common good recommended practice on the Go community. "A little copying is better than a little dependency." Watch "Go Proverbs", by Rob Pike. https://go-proverbs.github.io https://www.youtube.com/watch?v=PAAkCSZUG1c&t=9m28s

Index

Constants

This section is empty.

Variables

var Licenses = []License{
	License{
		Name:        "Go",
		Package:     "github.com/golang/go",
		LicensePath: "extra/licenses/GOLANG_LICENSE",
	},
	License{
		Name:        "moby",
		Package:     "github.com/moby/moby",
		Notes:       "modified",
		LicensePath: "extra/licenses/DOCKER_LICENSE",
	},
	License{
		Name:        "color",
		Package:     "github.com/fatih/color",
		Notes:       "heavily modified",
		LicensePath: "extra/licenses/COLOR_LICENSE",
	},
}

Licenses of extra dependency that are used on binary files, but instead of being availble on the vendor directory, are copied somewhere else.

Functions

This section is empty.

Types

type License

type License struct {
	Name        string
	Package     string
	Notes       string
	LicensePath string
}

License structure

func (*License) Get

func (l *License) Get() ([]byte, error)

Get license

Jump to