list

package
v1.0.0-alpha-44 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 25, 2016 License: MIT Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Filter

type Filter struct {
	Project    string
	Containers []string
}

Filter parameters for the list command

type List

type List struct {
	Detailed              bool
	Filter                Filter
	Projects              []projects.Project
	HandleProjectNotFound func() string
	HandleRequestError    func(error) string
	// contains filtered or unexported fields
}

List containers object

func New

func New(filter Filter) *List

New creates a list using the values of a passed Filter

func (*List) Print

func (l *List) Print()

Print containers

type Watcher

type Watcher struct {
	List            *List
	PoolingInterval time.Duration
	StopCondition   (func() bool)

	End      chan bool
	Teardown func() string
	// contains filtered or unexported fields
}

Watcher structure

func NewWatcher

func NewWatcher(list *List) *Watcher

NewWatcher creates a list watcher for a given List

func (*Watcher) Start

func (w *Watcher) Start()

Start for Watcher

func (*Watcher) Stop

func (w *Watcher) Stop()

Stop for Watcher

Jump to