login

package
v1.0.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 10, 2017 License: MIT Imports: 19 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CancelCommand

func CancelCommand(s string) error

CancelCommand creates a 'cancelled command' error so the system can end the program with exit code 0 when a user cancels a command on the CLI prompt

Types

type Authentication

type Authentication struct {
	NoLaunchBrowser bool
	Domains         status.Domains
	TipCommands     bool
	// contains filtered or unexported fields
}

Authentication service

func (*Authentication) Run

func (a *Authentication) Run(ctx context.Context) error

Run authentication process

type CanceledCommand

type CanceledCommand struct {
	// contains filtered or unexported fields
}

CanceledCommand skipped / canceled by the user

func (CanceledCommand) Error

func (cc CanceledCommand) Error() string

Jump to