package
Version:
v1.0.0-alpha-112
Opens a new window with list of versions in this module.
Published: May 11, 2017
License: MIT
Opens a new window with license information.
Imports: 14
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func OAuthTokenFromBasicAuth(remoteAddress, username, password string) (token string, err error)
OAuthTokenFromBasicAuth gets a token from a Basic Auth flow
Service server for receiving JSON Web Token
Credentials for authenticated user or error, it blocks until the information is available
Source Files
¶
Click to show internal directories.
Click to hide internal directories.