Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Prompt ¶
Prompt returns a prompt to receive the value of a parameter. If the key is on a secret keys list it suppresses the feedback.
func SelectOption ¶
SelectOption prompts for an option from a list
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.