package
Version:
v1.2.6
Opens a new window with list of versions in this module.
Published: Jan 11, 2018
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Client for the services
IsUp is returned if the infrastructure is up
UnsafeGet is a unsafe getter for the status
See get() method below to understand why.
It is exported here to use for domains.
type Domains struct {
Infrastructure string `json:"infrastructure"`
Service string `json:"service"`
}
Domains of the infrastructure
type Status struct {
Status string `json:"status"`
Version string `json:"version"`
Domains Domains `json:"domains"`
}
Status of the Backend
Source Files
¶
Click to show internal directories.
Click to hide internal directories.