templates

package
v1.1.9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 25, 2017 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute(format string, data interface{}) (string, error)

Execute template with format and data values

func ExecuteOrList

func ExecuteOrList(format string, data interface{}) (string, error)

ExecuteOrList executes the Execute function if format is not empty, otherwise, it returns all as a JSON

Types

This section is empty.

Jump to