package
Version:
v1.0.0-alpha-99
Opens a new window with list of versions in this module.
Published: Apr 12, 2017
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type User struct {
ID string `json:"id,omitempty"`
Email string `json:"email"`
Password string `json:"password"`
Name string `json:"name"`
}
User on the infrastructure
Source Files
¶
Click to show internal directories.
Click to hide internal directories.