usercontext

package
v1.0.0-alpha-66 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 11, 2016 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrContainerInProjectRoot = errors.New("Container and project definition files at the same directory level")

ErrContainerInProjectRoot happens when a project.json and container.json is found at the same directory level

Functions

func GetContainerRootDirectory

func GetContainerRootDirectory(delimiter string) (string, error)

GetContainerRootDirectory returns container dir for the current scope

func GetProjectRootDirectory

func GetProjectRootDirectory(delimiter string) (string, error)

GetProjectRootDirectory returns project dir for the current scope

Types

type Context

type Context struct {
	Scope         string
	ProjectRoot   string
	ContainerRoot string
	Remote        string
	RemoteAddress string
	Endpoint      string
	Username      string
	Password      string
	Token         string
}

Context structure

func Get

func Get() (*Context, error)

Get returns a Context object with the current scope

Jump to