package
Version:
v1.0.0-alpha-90
Opens a new window with list of versions in this module.
Published: Mar 16, 2017
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Debug(a ...interface{})
Debug prints verbose messages to stderr on verbose mode
IsUnsafeMode checks if the unsafe verbose mode is on
SafeEscapeSlice of strings
Source Files
¶
Click to show internal directories.
Click to hide internal directories.