package
Version:
v1.2.6
Opens a new window with list of versions in this module.
Published: Jan 11, 2018
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
CancelCommand creates a 'cancelled command' error
so the system can end the program with exit code 0
when a user cancels a command on the CLI prompt
Skip creates a 'quietly cancelled command'
type Command ¶
added in
v1.0.18
Command skipped / canceled by the user
func (Command) Error ¶
added in
v1.0.18
func (Command) Quiet ¶
added in
v1.2.6
Quiet tells whether the error message should be print on termination
Source Files
¶
Click to show internal directories.
Click to hide internal directories.