canceled

package
v1.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 1, 2017 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CancelCommand

func CancelCommand(s string) error

CancelCommand creates a 'cancelled command' error so the system can end the program with exit code 0 when a user cancels a command on the CLI prompt

Types

type Command added in v1.0.18

type Command struct {
	// contains filtered or unexported fields
}

Command skipped / canceled by the user

func (Command) Error added in v1.0.18

func (cc Command) Error() string

Jump to