package
Version:
v1.2.0
Opens a new window with list of versions in this module.
Published: Nov 1, 2017
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
CancelCommand creates a 'cancelled command' error
so the system can end the program with exit code 0
when a user cancels a command on the CLI prompt
type Command ¶
added in
v1.0.18
Command skipped / canceled by the user
func (Command) Error ¶
added in
v1.0.18
Source Files
¶
Click to show internal directories.
Click to hide internal directories.