Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // NoColor defines if the output is colorized or not. NoColor = false // NoColorFlag is set by the global --no-color NoColorFlag = false )
var BlockPalette = [][]Attribute{ []Attribute{BgHiRed, FgBlack}, []Attribute{BgHiGreen, FgBlack}, []Attribute{BgHiYellow, FgBlack}, []Attribute{BgHiBlue, FgBlack}, []Attribute{BgHiMagenta, FgBlack}, }
BlockPalette is a basic text on background palette of colors for terminal
var TextPalette = [][]Attribute{ []Attribute{FgHiRed}, []Attribute{FgHiGreen}, []Attribute{FgHiYellow}, []Attribute{FgHiBlue}, []Attribute{FgHiMagenta}, }
TextPalette is a basic foreground-only palette of colors for terminal
Functions ¶
Types ¶
type Attribute ¶
type Attribute int
Attribute defines a single SGR Code
const ( Reset Attribute = iota Bold Faint Italic Underline BlinkSlow BlinkRapid ReverseVideo Concealed CrossedOut )
Base attributes
Foreground text colors
const ( FgHiBlack Attribute = iota + 90 FgHiRed FgHiGreen FgHiYellow FgHiBlue FgHiMagenta FgHiCyan FgHiWhite )
Foreground Hi-Intensity text colors
Background text colors
Click to show internal directories.
Click to hide internal directories.