createctx

package
v1.0.0-alpha.16 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 11, 2016 License: MIT Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// ErrContainerPath indicates an invalid container location
	ErrContainerPath = errors.New("A container immediate parent dir must be the root of a project")

	// ErrProjectPath indicates an invalid project location
	ErrProjectPath = errors.New("A project can not have another project as its parent")

	// ErrInvalidID indicates an invalid resource ID (such as empty string)
	ErrInvalidID = errors.New("Value for ID is invalid")

	// ErrProjectAlreadyExists indicates that a project already exists
	ErrProjectAlreadyExists = errors.New("Invalid path for new configuration: project already exists")

	// ErrContainerAlreadyExists indicates that a container already exists
	ErrContainerAlreadyExists = errors.New("Invalid path for new configuration: container already exists")
)

Functions

func New

func New(id, directory string) error

New creates a resource

Types

This section is empty.

Jump to