Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrMissingHook is used when the main hook action is missing ErrMissingHook = errors.New("Missing hook.") )
Functions ¶
func RunAndExitOnFailure ¶
func RunAndExitOnFailure(command string)
RunAndExitOnFailure inheriting stderr and stdout, but kill itself on error
Types ¶
type Hooks ¶
type Hooks struct {
BeforeBuild string `json:"before_build" mapstructure:"before_build"`
Build string `json:"build"`
AfterBuild string `json:"after_build" mapstructure:"after_build"`
BeforeDeploy string `json:"before_deploy" mapstructure:"before_deploy"`
Deploy string `json:"deploy"`
AfterDeploy string `json:"after_deploy" mapstructure:"after_deploy"`
}
Hooks (after / deploy / main action)
Click to show internal directories.
Click to hide internal directories.