Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrExitCodeNotAvailable is used for exit code retrieval failure ErrExitCodeNotAvailable = errors.New("Exit code not available") )
Functions ¶
func GetExitCode ¶
GetExitCode tries to retrieve the exit code from an exit error
func GetLogoutHome ¶
func GetLogoutHome() string
GetLogoutHome gets mocked logged out user's home path
func GetRegularHome ¶
func GetRegularHome() string
GetRegularHome gets mocked regular user's home path
Types ¶
Click to show internal directories.
Click to hide internal directories.