Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CancelCommand ¶
CancelCommand creates a 'cancelled command' error so the system can end the program with exit code 0 when a user cancels a command on the CLI prompt
Types ¶
type Authentication ¶
type Authentication struct {
NoLaunchBrowser bool
Domains status.Domains
TipCommands bool
// contains filtered or unexported fields
}
Authentication service
type CanceledCommand ¶
type CanceledCommand struct {
// contains filtered or unexported fields
}
CanceledCommand skipped / canceled by the user
func (CanceledCommand) Error ¶
func (cc CanceledCommand) Error() string
Click to show internal directories.
Click to hide internal directories.