loginserver

package
v1.0.0-alpha-95 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 31, 2017 License: MIT Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func OAuthTokenFromBasicAuth

func OAuthTokenFromBasicAuth(username, password string) (token string, err error)

OAuthTokenFromBasicAuth gets a token from a Basic Auth flow

Types

type Service

type Service struct {
	// contains filtered or unexported fields
}

Service server for receiving JSON Web Token

func (*Service) Credentials

func (s *Service) Credentials() (username string, token string, err error)

Credentials for authenticated user or error, it blocks until the information is available

func (*Service) Listen

func (s *Service) Listen(ctx context.Context) (address string, err error)

Listen for requests

func (*Service) Serve

func (s *Service) Serve() error

Serve HTTP requests

Jump to