Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func OAuthTokenFromBasicAuth ¶
OAuthTokenFromBasicAuth gets a token from a Basic Auth flow
Types ¶
type Service ¶
type Service struct {
Infrastructure string
// contains filtered or unexported fields
}
Service server for receiving JSON Web Token
func (*Service) Credentials ¶
Credentials for authenticated user or error, it blocks until the information is available
Click to show internal directories.
Click to hide internal directories.