Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var PoolingInterval = time.Second
PoolingInterval is the time between retries
var SeverityToLevel = map[string]int{
"critical": 2,
"error": 3,
"warning": 4,
"info": 6,
"debug": 7,
}
SeverityToLevel map
Functions ¶
func GetUnixTimestamp ¶
GetUnixTimestamp gets the Unix timestamp in seconds from a friendly string. Be aware that the dashboard is using ms, not s.
Types ¶
type Client ¶ added in v1.1.5
Client for the services
type Filter ¶
type Filter struct {
Project string `json:"-"`
Service string `json:"serviceId,omitempty"`
Instance string `json:"containerUid,omitempty"`
Level int `json:"level,omitempty"`
Since string `json:"start,omitempty"`
}
Filter structure
type Log ¶
type Log struct {
ServiceID string `json:"serviceId"`
ContainerUID string `json:"containerUid"`
Build bool `json:"build"`
DeployUID string `json:"deployUid"`
ProjectID string `json:"projectId"`
Level int `json:"level"`
Message string `json:"message"`
Severity string `json:"severity"`
Timestamp string `json:"timestamp"`
}
Log structure
Click to show internal directories.
Click to hide internal directories.