logs

package
v1.0.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 10, 2017 License: MIT Imports: 17 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var PoolingInterval = time.Second

PoolingInterval is the time between retries

var SeverityToLevel = map[string]int{
	"critical": 2,
	"error":    3,
	"warning":  4,
	"info":     6,
	"debug":    7,
}

SeverityToLevel map

Functions

func GetLevel

func GetLevel(severityOrLevel string) (int, error)

GetLevel to get level from severity or itself

func GetUnixTimestamp

func GetUnixTimestamp(since string) (int64, error)

GetUnixTimestamp gets the Unix timestamp in seconds from a friendly string. Be aware that the dashboard is using ms, not s.

func List

func List(ctx context.Context, filter *Filter) error

List logs

func Watch

func Watch(watcher *Watcher)

Watch logs

Types

type Filter

type Filter struct {
	Project  string `json:"-"`
	Service  string `json:"serviceId,omitempty"`
	Instance string `json:"containerUid,omitempty"`
	Level    int    `json:"level,omitempty"`
	Since    string `json:"start,omitempty"`
}

Filter structure

type Log

type Log struct {
	ServiceID    string `json:"serviceId"`
	ContainerUID string `json:"containerUid"`
	Build        bool   `json:"build"`
	DeployUID    string `json:"deployUid"`
	ProjectID    string `json:"projectId"`
	Level        int    `json:"level"`
	Message      string `json:"message"`
	Severity     string `json:"severity"`
	Timestamp    int64  `json:"timestamp"`
}

Log structure

func GetList

func GetList(ctx context.Context, filter *Filter) ([]Log, error)

GetList logs

type Watcher

type Watcher struct {
	Filter          *Filter
	PoolingInterval time.Duration
	// contains filtered or unexported fields
}

Watcher structure

func (*Watcher) Start

func (w *Watcher) Start()

Start for Watcher

func (*Watcher) Stop

func (w *Watcher) Stop()

Stop for Watcher

Jump to