logs

package
v1.0.0-alpha.16 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 11, 2016 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var PoolingInterval = time.Second

PoolingInterval is the time between retries

var SeverityToLevel = map[string]int{
	"critical": 2,
	"error":    3,
	"warning":  4,
	"info":     6,
	"debug":    7,
}

SeverityToLevel map

Functions

func GetLevel

func GetLevel(severityOrLevel string) (int, error)

GetLevel to get level from severity or itself

func GetUnixTimestamp

func GetUnixTimestamp(since string) (int64, error)

GetUnixTimestamp gets the Unix timestamp in seconds from a friendly string. Be aware that the dashboard is using ms, not s.

func List

func List(filter *Filter)

List logs

func Watch

func Watch(watcher *Watcher)

Watch logs

Types

type Filter

type Filter struct {
	Project   string `json:"-"`
	Container string `json:"containerId,omitempty"`
	Instance  string `json:"containerUid,omitempty"`
	Level     int    `json:"level,omitempty"`
	Since     string `json:"start,omitempty"`
}

Filter structure

type Logs

type Logs struct {
	ContainerID  string `json:"containerId"`
	ContainerUID string `json:"containerUid"`
	ProjectID    string `json:"projectId"`
	Level        int    `json:"level"`
	Message      string `json:"message"`
	Severity     string `json:"severity"`
	Timestamp    string `json:"timestamp"`
}

Logs structure

func GetList

func GetList(filter *Filter) []Logs

GetList logs

type Watcher

type Watcher struct {
	Filter          *Filter
	PoolingInterval time.Duration
	// contains filtered or unexported fields
}

Watcher structure

func (*Watcher) Start

func (w *Watcher) Start()

Start for Watcher

func (*Watcher) Stop

func (w *Watcher) Stop()

Stop for Watcher

Jump to