Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var PoolingInterval = time.Second
PoolingInterval is the time between retries
var SeverityToLevel = map[string]int{
"critical": 2,
"error": 3,
"warning": 4,
"info": 6,
"debug": 7,
}
SeverityToLevel map
Functions ¶
func GetUnixTimestamp ¶
GetUnixTimestamp gets the Unix timestamp in seconds from a friendly string. Be aware that the dashboard is using ms, not s.
Types ¶
type Filter ¶
type Filter struct {
Project string `json:"-"`
Container string `json:"containerId,omitempty"`
Instance string `json:"containerUid,omitempty"`
Level int `json:"level,omitempty"`
Since string `json:"start,omitempty"`
}
Filter structure
Click to show internal directories.
Click to hide internal directories.