Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Total = 100
Total of intervals
var Width = 40
Width of standard progress bar
Functions ¶
Types ¶
type Bar ¶
type Bar struct {
// Name to prepend to the progress bar
Name string
// Prepend value to the progress bar after its name
Prepend string
// Append value to the progress bar
Append string
// contains filtered or unexported fields
}
Bar holds the progress bar data
func (*Bar) Flow ¶
func (b *Bar) Flow()
Flow repeats flowing the progress bar from begin to end continuously
Click to show internal directories.
Click to hide internal directories.