update

package
v1.1.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 5, 2017 License: MIT Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var AppID = "app_g12mjgk2k9D"

AppID is Equinox's app ID for this tool

var PublicKey = []byte(`
-----BEGIN ECDSA PUBLIC KEY-----
MHYwEAYHKoZIzj0CAQYFK4EEACIDYgAE1+wgAlkBJRmtRwmZWfq9fa8dBlJ929hM
BzASHioHo6RP1V+4EKnAxaYXN4eWlgalxQ2BEr8TqYRM+uHPizteVR11wKfsO6S0
GENiOKpfivw5FIiTN14MZeMTagiKJUOq
-----END ECDSA PUBLIC KEY-----
`)

PublicKey is the public key for the certificate used with Equinox

Functions

func ApplyTransitions

func ApplyTransitions(pastVersion string)

ApplyTransitions applies transition / fixes functions for updating this tool after updates It is assumed that this is called only manually, but it is not guaranteed

func GetReleaseChannel

func GetReleaseChannel() string

GetReleaseChannel gets the channel user has used last time (or stable)

func NotifierCheck

func NotifierCheck() error

NotifierCheck enquires equinox if a new version is available

func Notify

func Notify()

Notify is called every time this tool executes to verify if it is outdated

func Update

func Update(channel string) error

Update this tool

Types

type Checker

type Checker struct {
	Cue chan error
}

Checker for update checks

func (*Checker) Check

func (c *Checker) Check()

Check if an update is available on a goroutine

func (*Checker) Feedback

func (c *Checker) Feedback()

Feedback of an update check

type Transition

type Transition struct {
	Description func() string
	Test        func(pastVersion string) bool
	Apply       func() error
}

Transition for update changes

Jump to