Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var AppID = "app_6vxvxHVfPgz"
AppID is Equinox's app ID for this tool
var ErrMasterVersion = errors.New(
"You must update a development version manually with git")
ErrMasterVersion triggered when trying to update a development version
var PublicKey = []byte(`
-----BEGIN ECDSA PUBLIC KEY-----
MHYwEAYHKoZIzj0CAQYFK4EEACIDYgAE1+wgAlkBJRmtRwmZWfq9fa8dBlJ929hM
BzASHioHo6RP1V+4EKnAxaYXN4eWlgalxQ2BEr8TqYRM+uHPizteVR11wKfsO6S0
GENiOKpfivw5FIiTN14MZeMTagiKJUOq
-----END ECDSA PUBLIC KEY-----
`)
PublicKey is the public key for the certificate used with Equinox
Functions ¶
func GetReleaseChannel ¶
func GetReleaseChannel() string
GetReleaseChannel gets the channel user has used last time (or stable)
func NotifierCheck ¶
func NotifierCheck() error
NotifierCheck enquires equinox if a new version is available
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.