usercontext

package
v1.0.0-alpha-26 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 1, 2016 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// ErrContainerInProjectRoot happens when a project.json and container.json is found at the same directory level
	ErrContainerInProjectRoot = errors.New("Container and project definition files at the same directory level")
)

Functions

This section is empty.

Types

type Context

type Context struct {
	Scope         string
	ProjectRoot   string
	ContainerRoot string
	Remote        string
	Endpoint      string
	Username      string
	Password      string
	Token         string
}

Context structure

func Get

func Get() (*Context, error)

Get returns a Context object with the current scope

Jump to