usercontext

package
v1.0.0-alpha-86 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 14, 2017 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrContainerInProjectRoot = errors.New("Container and project definition files at the same directory level")

ErrContainerInProjectRoot happens when a project.json and container.json is found at the same directory level

Functions

func GetContainerRootDirectory

func GetContainerRootDirectory(delimiter string) (string, error)

GetContainerRootDirectory returns container dir for the current scope

func GetProjectRootDirectory

func GetProjectRootDirectory(delimiter string) (string, error)

GetProjectRootDirectory returns project dir for the current scope

Types

type Context

type Context struct {
	Scope         Scope
	ProjectRoot   string
	ContainerRoot string
	Remote        string
	RemoteAddress string
	Endpoint      string
	Username      string
	Password      string
	Token         string
}

Context structure

func (*Context) Load

func (cx *Context) Load() error

Load a Context object with the current scope

type Scope

type Scope string

Scope is the type for the current mode of the CLI tool (based on current working directory)

const (
	// GlobalScope is the scope when no container on project or project is active
	GlobalScope Scope = "global"

	// ProjectScope is the scope for when a project is active, but no container is active
	ProjectScope Scope = "project"

	// ContainerScope is the scope for when a container on a project is active
	ContainerScope Scope = "container"
)

Jump to