Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrContainerInProjectRoot = errors.New("Container and project definition files at the same directory level")
ErrContainerInProjectRoot happens when a project.json and container.json is found at the same directory level
Functions ¶
func GetContainerRootDirectory ¶
GetContainerRootDirectory returns container dir for the current scope
func GetProjectRootDirectory ¶
GetProjectRootDirectory returns project dir for the current scope
Types ¶
type Context ¶
type Context struct {
Scope Scope
ProjectRoot string
ContainerRoot string
Remote string
RemoteAddress string
Endpoint string
Username string
Password string
Token string
}
Context structure
type Scope ¶
type Scope string
Scope is the type for the current mode of the CLI tool (based on current working directory)
const ( // GlobalScope is the scope when no container on project or project is active GlobalScope Scope = "global" // ProjectScope is the scope for when a project is active, but no container is active ProjectScope Scope = "project" // ContainerScope is the scope for when a container on a project is active ContainerScope Scope = "container" )
Click to show internal directories.
Click to hide internal directories.