verbose

package
v1.2.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 10, 2017 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// Enabled flag
	Enabled = false

	// Deferred flag to only print debugging on end of program execution
	Deferred = false

	// ErrStream is the stream for errors
	ErrStream io.Writer = os.Stderr
)

Functions

func Debug

func Debug(a ...interface{})

Debug prints verbose messages to stderr on verbose mode

func IsUnsafeMode

func IsUnsafeMode() bool

IsUnsafeMode checks if the unsafe verbose mode is on

func PrintDeferred added in v1.0.8

func PrintDeferred()

PrintDeferred debug messages

func SafeEscape

func SafeEscape(value string) string

SafeEscape string

func SafeEscapeSlice

func SafeEscapeSlice(values []string) string

SafeEscapeSlice of strings

Types

This section is empty.

Jump to