verbose

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 8, 2017 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// Enabled flag
	Enabled = false

	// Defered flag to only print debugging on end of program execution
	Defered = false

	// ErrStream is the stream for errors
	ErrStream io.Writer = os.Stderr
)

Functions

func Debug

func Debug(a ...interface{})

Debug prints verbose messages to stderr on verbose mode

func IsUnsafeMode

func IsUnsafeMode() bool

IsUnsafeMode checks if the unsafe verbose mode is on

func PrintDefered

func PrintDefered()

PrintDefered debug messages

func SafeEscape

func SafeEscape(value string) string

SafeEscape string

func SafeEscapeSlice

func SafeEscapeSlice(values []string) string

SafeEscapeSlice of strings

Types

This section is empty.

Jump to